Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(790)

Unified Diff: Source/core/html/HTMLLinkElement.cpp

Issue 23516012: Rename StyleSheetCollections to StyleEngine. (Closed) Base URL: svn://svn.chromium.org/blink/trunk
Patch Set: Created 7 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « Source/core/dom/shadow/ShadowRoot.cpp ('k') | Source/core/html/HTMLQuoteElement.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: Source/core/html/HTMLLinkElement.cpp
diff --git a/Source/core/html/HTMLLinkElement.cpp b/Source/core/html/HTMLLinkElement.cpp
index cbc8b9a09250c04059b15631d39fbfb0155c1fa5..e41bf00e2ea4a453d81439362cea59f73085fc10 100644
--- a/Source/core/html/HTMLLinkElement.cpp
+++ b/Source/core/html/HTMLLinkElement.cpp
@@ -36,7 +36,7 @@
#include "core/dom/Document.h"
#include "core/dom/Event.h"
#include "core/dom/EventSender.h"
-#include "core/dom/StyleSheetCollections.h"
+#include "core/dom/StyleEngine.h"
#include "core/fetch/CSSStyleSheetResource.h"
#include "core/fetch/FetchRequest.h"
#include "core/fetch/ResourceFetcher.h"
@@ -80,7 +80,7 @@ HTMLLinkElement::~HTMLLinkElement()
m_link.clear();
if (inDocument())
- document().styleSheetCollections()->removeStyleSheetCandidateNode(this);
+ document().styleEngine()->removeStyleSheetCandidateNode(this);
linkLoadEventSender().cancelEvent(this);
}
@@ -198,7 +198,7 @@ Node::InsertionNotificationRequest HTMLLinkElement::insertedInto(ContainerNode*
if (m_isInShadowTree)
return InsertionDone;
- document().styleSheetCollections()->addStyleSheetCandidateNode(this, m_createdByParser);
+ document().styleEngine()->addStyleSheetCandidateNode(this, m_createdByParser);
process();
return InsertionDone;
@@ -216,7 +216,7 @@ void HTMLLinkElement::removedFrom(ContainerNode* insertionPoint)
ASSERT(!linkStyle() || !linkStyle()->hasSheet());
return;
}
- document().styleSheetCollections()->removeStyleSheetCandidateNode(this);
+ document().styleEngine()->removeStyleSheetCandidateNode(this);
RefPtr<StyleSheet> removedSheet = sheet();
@@ -496,7 +496,7 @@ void LinkStyle::addPendingSheet(PendingSheetType type)
if (m_pendingSheetType == NonBlocking)
return;
- m_owner->document().styleSheetCollections()->addPendingSheet();
+ m_owner->document().styleEngine()->addPendingSheet();
}
void LinkStyle::removePendingSheet(RemovePendingSheetNotificationType notification)
@@ -507,8 +507,8 @@ void LinkStyle::removePendingSheet(RemovePendingSheetNotificationType notificati
if (type == None)
return;
if (type == NonBlocking) {
- // Tell StyleSheetCollections to re-compute styleSheets of this m_owner's treescope.
- m_owner->document().styleSheetCollections()->modifiedStyleSheetCandidateNode(m_owner);
+ // Tell StyleEngine to re-compute styleSheets of this m_owner's treescope.
+ m_owner->document().styleEngine()->modifiedStyleSheetCandidateNode(m_owner);
// Document::removePendingSheet() triggers the style selector recalc for blocking sheets.
// FIXME: We don't have enough knowledge at this point to know if we're adding or removing a sheet
// so we can't call addedStyleSheet() or removedStyleSheet().
@@ -516,10 +516,10 @@ void LinkStyle::removePendingSheet(RemovePendingSheetNotificationType notificati
return;
}
- m_owner->document().styleSheetCollections()->removePendingSheet(m_owner,
+ m_owner->document().styleEngine()->removePendingSheet(m_owner,
notification == RemovePendingSheetNotifyImmediately
- ? StyleSheetCollections::RemovePendingSheetNotifyImmediately
- : StyleSheetCollections::RemovePendingSheetNotifyLater);
+ ? StyleEngine::RemovePendingSheetNotifyImmediately
+ : StyleEngine::RemovePendingSheetNotifyLater);
}
void LinkStyle::setDisabledState(bool disabled)
« no previous file with comments | « Source/core/dom/shadow/ShadowRoot.cpp ('k') | Source/core/html/HTMLQuoteElement.cpp » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698